{% extends 'posts/base.html' %}
{% load blog_tags %}
{% block title %} {{ blog_name.title }} {% endblock %}
{% block blog_content %}
<div class="row col-sm-12 col-md-9 blog-container-left">
<!-- breadcrumbs-schema -->
<ol itemscope itemtype="http://schema.org/BreadcrumbList" class="breadcrumb">
  <li itemprop="itemListElement" itemscope
      itemtype="http://schema.org/ListItem">
    <a itemprop="item" href="/">
        <span itemprop="name">Blog</span></a>
    <meta itemprop="position" content="1" />
  </li>
  <li itemprop="itemListElement" itemscope
      itemtype="http://schema.org/ListItem">
    <a itemprop="item" href="{% url 'selected_category' category_slug=blog_name.category.slug %}">
      <span itemprop="name"> {{ blog_name.category }}</span></a>
    <meta itemprop="position" content="2" />
  </li>
  <li itemprop="itemListElement" itemscope
      itemtype="http://schema.org/ListItem">
    <a itemprop="item" href="">
      <span itemprop="name"> {{ blog_name.title }}</span></a>
    <meta itemprop="position" content="3" />
  </li>
</ol>
<!-- end -->
  <div class="blogs" itemtype="http://schema.org/BlogPosting">
    <!-- share -->
    <div>
    <a target="_blank" href="https://www.facebook.com/sharer/sharer.php?u={{short_url}}&t={{blog_name.title}}" class="facebook"><i class="fa fa-facebook"></i></a>
    <a target="_blank" href="https://plus.google.com/share?hl=en-US&url={{short_url}}" class="google-plus"><i class="fa fa-google-plus"></i></a>
    <a target="_blank" href="https://twitter.com/intent/tweet?text={{blog_name.title}}&url={{short_url}}&via={{blog_title}}" class="twitter"><i class="fa fa-twitter"></i></a>
    <a target="_blank" href="https://www.linkedin.com/cws/share?url={{ short_url }}&token=&isFramed=true" class="linkedin"><i class="fa fa-linkedin"></i></a>
    </div>
    <ul class="blog-list">
      <table align="center" class="table table-bordered">
        <thead>
          <th>
            <span itemprop="blog-article">Title: <span itemprop="name headline">{{ blog_name.title }}</span> </span>
          </th>
        </thead>
        <tbody>
          <tr>
            <td>
              <span itemprop="author" itemtype="http://schema.org/Person">
                <strong>Author</strong>:
                <span itemprop="name">{{ blog_name.user }}</span>
              </span>
            </td>
          </tr>
          <tr>
            <td><strong>Content</strong>: <div class="content" itemprop="articleBody">{{ blog_name.content|safe }}</div></td>
          </tr>
          <tr>
            <td class="widget tags"><strong>Tags</strong>:
              {% for tag in blog_name.tags.all %}
              <a href="{% url 'selected_tag' tag_slug=tag.slug %}" ><i class="fa fa-tags"></i> {{ tag }}</a>
              {% endfor %}
            </td>
          </tr>
          <tr>
            <td><strong>Keywords</strong>: <div itemprop="keywords" itemtype="http://schema.org/keywords">{{ blog_name.keywords|safe }}</div></td>
          </tr>
        </tbody>
      </table>
    </ul>
  </div>
  <div id="disqus_thread"></div>
<script>
    /**
     *  RECOMMENDED CONFIGURATION VARIABLES: EDIT AND UNCOMMENT THE SECTION BELOW TO INSERT DYNAMIC VALUES FROM YOUR PLATFORM OR CMS.
     *  LEARN WHY DEFINING THESE VARIABLES IS IMPORTANT: https://disqus.com/admin/universalcode/#configuration-variables
     */
    var disqus_config = function () {
        this.page.identifier = '{{ blog_name.slug }}';
        this.page.title = '{{ blog_name.title }}';
    };
    var disqus_shortname = '{{ disqus_shortname }}';
    (function() {  // REQUIRED CONFIGURATION VARIABLE: EDIT THE SHORTNAME BELOW
        var d = document, s = d.createElement('script');

        s.src = '//' + disqus_shortname + '.disqus.com/embed.js';
        // IMPORTANT: Replace EXAMPLE with your forum shortname!

        s.setAttribute('data-timestamp', +new Date());
        (d.head || d.body).appendChild(s);
    })();
</script>
<noscript>Please enable JavaScript to view the <a href="https://disqus.com/?ref_noscript" rel="nofollow">comments powered by Disqus.</a></noscript>
</div>
{% endblock %}
{% block js_script %}
<script type="text/javascript"></script>
{% endblock %}